#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Utilities for correcting raw data.
"""
from .candidate_party import candidate_party


__all__ = ("candidate_party",)
